from hurodes.joint_mapping.double_link_solver import DoubleLinkSolver

solver_dict = {
    "double_link": DoubleLinkSolver,
}

__all__ = ["solver_dict"]
